@@ -1446,7 +1446,8 @@ typedef enum cpu_arch {
   arch_arm,
   arch_mips,
   arch_x86_64,
-  arch_aarch64
+  arch_aarch64,
+  arch_riscv
 } hd_cpu_arch_t;
 
 /**
